/// <reference types="node" />
import { PackageJson, PartialDeep, TsConfigJson } from "type-fest";
declare type MaybePromise<T> = T | Promise<T>;
declare type Options = PartialDeep<{
    /** @default utf-8 */
    encoding: BufferEncoding;
    /**
     * If `false`, FS or JSON errors will be ignored
     * @default true
     *  */
    throws: boolean;
    /** @default "throw" (silent if throws: false) */
    ifFieldIsMissing: "throw" | "skip" | "add";
    /**
     * - throw - throws (silent if throws: false)
     *-  skip - won't call the function
     * - pass - pass the `undefined` value
     * @default "throw"
     * */
    ifFieldIsMissingForSetter: "throw" | "skip" | "pass";
    /**
     * - null - disable formatting
     * - hard - one hard tab \t
     * - number - number of spaces
     * @default "preserve"
     *  */
    tabSize: null | number | "preserve" | "hard";
}>;
declare type ModifyFields<T extends object> = {
    [K in keyof T]?: T[K] | ((oldValue: T[K], json: T) => T[K]);
};
declare type ModifyFunction<T> = (oldJson: T) => MaybePromise<T>;
declare type JsonRoot = number | string | boolean | null | object | any[];
export declare type ModifyJsonFileFunction<T extends JsonRoot> = (path: string, modifyFields: T extends object ? ModifyFields<T> | ModifyFunction<T> : ModifyFunction<T>, options?: Partial<Options>) => Promise<void>;
declare type ModifyJsonFileGenericFunction = <T extends JsonRoot = object>(path: string, modifyFields: T extends object ? ModifyFields<T> | ModifyFunction<T> : ModifyFunction<T>, options?: Partial<Options>) => Promise<void>;
/** It's just Error */
/**
 * modifies **original** JSON file
 * You can pass generic, that reflects the structure of original JSON file
 *
 * @param modifyFields If file contents is object, you can pass fields to merge or callback (can be async). If callback is passed, JSON fields won't be merged. In case if file contents is not an object, you must pass callback.
 */
export declare const modifyJsonFile: ModifyJsonFileGenericFunction;
/**
 * Almost the same is sindresorhus/write-pkg, but with proper typing support and setters for fields
 */
export declare const modifyPackageJsonFile: ModifyJsonFileFunction<PackageJson>;
export declare const modifyTsConfigJsonFile: ModifyJsonFileFunction<TsConfigJson>;
export {};
